import { ChangeEvent, useState } from "react";
import {
  Box,
  FormControl,
  FormControlLabel,
  FormLabel,
  Radio,
  RadioGroup,
  useRadioGroup,
  Tooltip,
  Typography,
} from "@mui/material";

import InfoIcon from "@icons/InfoIcon";

import type { QuizQuestionVariant } from "model/questionTypes/variant";
import CustomRadio from "@ui_kit/CustomRadio";
import RadioCheck from "@ui_kit/RadioCheck";
import RadioIcon from "@ui_kit/RadioIcon";

interface Props {
  question: QuizQuestionVariant;
}

export default function Variant({ question }: Props) {
  const [value, setValue] = useState<string | null>(null);

  const handleChange = (event: ChangeEvent<HTMLInputElement>) => {
    setValue((event.target as HTMLInputElement).value);
  };

  return (
    <FormControl fullWidth>
      <FormLabel id="quiz-question-radio-group" data-cy="question-title" sx={{color: "#000000", marginBottom: "20px", fontSize: "24px", fontWeight: 500}}>
        {question.title}
      </FormLabel>
      <RadioGroup
        aria-labelledby="quiz-question-radio-group"
        value={value}
        onChange={handleChange}
        sx={{
            flexDirection: "row",
            gap: "20px"
        }}
      >
        {question.content.variants
          .filter(({ answer }) => answer)
          .map((variant, index) => (
            <FormControlLabel
              key={index}
              value={variant.answer}
              data-cy="variant-answer"
              labelPlacement="start"
              sx={{borderRadius: "12px",
                  border: value === value ? "1px solid #7E2AEA" : "1px solid #9A9AAF",
                  padding: "20px",
                  justifyContent: "space-between",
                  maxWidth: "685px",
                  width: "100%",
                  margin: 0
              }}
              control={
                <Radio
                  inputProps={{
                    "data-cy": "variant-radio",
                  }}
                  checkedIcon={<RadioCheck />} icon={<RadioIcon />}
                />
              }
              label={
                <Box sx={{ display: "flex", alignItems: "center", gap: 2 }}>
                  <Typography>
                    {variant.answer}
                  </Typography>
                  {variant.hints && (
                    <Tooltip title={variant.hints} placement="right">
                      <Box>
                        <InfoIcon />
                      </Box>
                    </Tooltip>
                  )}
                </Box>
              }
            />
          ))}
      </RadioGroup>
    </FormControl>
  );
}
